import re
from django.conf import settings

RE_HEAD = re.compile("</head>")

ENABLED = getattr(settings, 'ANALYTICS_MIDDLEWARE_ENABLED', True)
SKIP_REQUESTS = getattr(settings, 'ANALYTICS_MIDDLEWARE_SKIP_REQUESTS', [])

PARAMS = {
    'account' : '',
    'domain': '',
    'allow_linker': 'true'
}
USER_PARAMS = getattr(settings, 'ANALYTICS_MIDDLEWARE_PARAMS', {'account':'',
                                                           'domain': ''})

PARAMS.update(USER_PARAMS)

DEFAULT_SCRIPT_TPL = """
<script type="text/javascript">

  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', '%(account)s']);
  _gaq.push(['_setDomainName', '%(domain)s']);
  _gaq.push(['_setAllowLinker', %(allow_linker)s]);
  _gaq.push(['_trackPageview']);

  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();

</script>
"""

SCRIPT_TPL = getattr(settings, 'ANALYTICS_MIDDLEWARE_SCRIPT_TPL',
                     DEFAULT_SCRIPT_TPL)
SCRIPT = SCRIPT_TPL % PARAMS


class AnalyticsMiddleware(object):

    def process_response(self, request, response):
        if not ENABLED:
            return response

        for skip_request in SKIP_REQUESTS:
            if skip_request(request):
                return response

        if 'text/html' in response['Content-Type']:
            response.content = RE_HEAD.sub("%s\n</head>" % SCRIPT, response.content)

        return response

